#
# spec file for package wf-shell
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define major_ver 0.9
%define minor_ver 0
Name:           wf-shell
Version:        %{major_ver}.%{minor_ver}
Release:        1.1
Summary:        A GTK3-based panel for wayfire
License:        MIT
URL:            https://wayfire.org/
Source0:        https://github.com/WayfireWM/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/WayfireWM/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz.sha256sum
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbusmenu-gtk3-0.4)
BuildRequires:  pkgconfig(gtk-layer-shell-0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(wayfire)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wf-config) >= %{major_ver}
BuildRequires:  pkgconfig(wlroots) >= 0.17.0

%description
wf-shell is a repository which contains the various components needed to built a fully functional DE based around wayfire. Currently it has only a GTK-based panel and background client.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}

%description devel
Development libraries for %{name}

%prep
echo "`grep %{name}-%{version}.tar.xz %{SOURCE1} | grep -Eo '^[0-9a-f]+'`  %{SOURCE0}" | sha256sum -c
%autosetup

%build
%meson
%meson_build

%install
%meson_install
install -D -m 0644 wf-shell.ini.example %{buildroot}%{_datadir}/wayfire/wf-shell.ini.example
%fdupes %{buildroot}%{_prefix}

%check
%meson_test

%files
%{_bindir}/wf-*
%{_bindir}/wayland-logout
%{_datadir}/wayfire/
%{_datadir}/wayfire/wf-shell.ini.example
%dir %{_datadir}/icons/hicolor/160x160
%dir %{_datadir}/icons/hicolor/160x160/apps
%{_datadir}/icons/*/*/*/*.png
%{_datadir}/icons/*/*/*/*.svg
%{_mandir}/man1/wayland-logout.1%{?ext_man}

%files devel
%{_libdir}/pkgconfig/wf-shell.pc

%changelog
* Mon Jan  6 2025 Shawn Dunn <sfalken@opensuse.org>
- Changed pkgconfig(wlroots) to >= 0.17.0
  * Multiple options available for wlroots
* Mon Aug 26 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.9.0:
  * Major new feature is CSS theming support.
  * initialize manager with NULL.
  * Fix excusive zone when zwf_shell_manager_v2 is unavailable.
  * Listen for toggle_menu event.
  * panel: middle click to close window.
  * Fix crash with parentheses in filenames.
  * wf-background: allow seamless background updates.
  * window-list: Allow smaller panel heights.
  * Install wayfire.png to hicolor icon theme.
  * bug fixes.
  * Add "Fill and Crop" option for wf-background. Pt 2.
  * window-list: use ~/.local/share when looking for apps / icons.
  * Check for and load absolute path icons in panel launchers.
  * Collection of Menu alterations.
  * menu: Allow sorting by relevance.
  * menu: Allow themed icon in panel.
  * window-list: Dragging files to window list and hovering
    activates window.
  * background: allow taking keyboard focus.
  * Visible separator.
  * panel: add css classes to widgets.
  * wf-panel: hot-reload css.
  * separator: css classname.
  * css examples.
  * background: free old image after transition.
  * window-list: additional classes for window state.
  * gtk-utils: set icon changes.
  * launcher: remove features.
  * tray: allow css styling.
  * launchers, tray: untheme button by default.
  * window-list: attach popup menu to button.
  * css: added classes to popovers.
  * Update gvc.
  * Move some more style code into CSS & misc extra CSS work.
  * menu: Fix resize in config.
* Thu Mar 14 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.8.1:
  * Ability to configure a binding to toggle the menu widget
    (from the wayfire-shell plugin in Wayfire).
  * SIGUSR1 can be used to change the background if multiple
    backgrounds are configured.
  * A few bug fixes.
* Mon Oct  9 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.8.0:
  * This version has a number of new widgets:
  - Tray.
  - Command-output for displaying output of commands in the panel.
  - Notifications.
  - Logout interface.
* Fri Dec  2 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update wlroots minimum version to spec.
* Wed Nov 30 2022 Dead Mozay <dead_mozay@opensuse.org>
- Set wlroots max version to spec.
* Wed Feb  3 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.7.0:
  * Compatible with Wayfire 0.7.x and wf-config 0.7.x
  * Only minor changes since 0.6.1, most notably there has been
    a new option for CSS theming: #77
* Fri Nov 13 2020 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.6.1:
  * No changelog was made available.
* Mon Nov  9 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.0:
  * No changelog was made available.
* Wed Aug  5 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.5.0:
  * No changelog was made available.
* Thu Apr 30 2020 Dead Mozay <dead_mozay@opensuse.org>
- Remove service
* Mon Mar 23 2020 dead_mozay@opensuse.org
- Update to version 0.4.0:
  * No changelog was made available.
* Tue Mar 17 2020 dead_mozay@opensuse.org
- Update to version 0.3:
  * No changelog was made available.
* Thu Oct  3 2019 dead_mozay@opensuse.org
- Update to version 0.1.git~20191002.513c22f:
  * No changelog was made available.
* Thu Oct  3 2019 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
